@@ -15,7 +15,7 @@ import (
 )
 
 func newInstallSystemdCommand() *cobra.Command {
-	var installSystemdCommand = &cobra.Command{
+	installSystemdCommand := &cobra.Command{
 		Use:   "install-systemd",
 		Short: "install a systemd unit (user)",
 		RunE:  installSystemdAction,
@@ -38,17 +38,18 @@ func installSystemdAction(cmd *cobra.Command, _ []string) error {
 		logrus.Infof("File %q already exists, overwriting", unitPath)
 	} else {
 		unitDir := filepath.Dir(unitPath)
-		if err := os.MkdirAll(unitDir, 0755); err != nil {
+		if err := os.MkdirAll(unitDir, 0o755); err != nil {
 			return err
 		}
 	}
-	if err := os.WriteFile(unitPath, unit, 0644); err != nil {
+	if err := os.WriteFile(unitPath, unit, 0o644); err != nil {
 		return err
 	}
 	logrus.Infof("Written file %q", unitPath)
 	args := [][]string{
 		{"daemon-reload"},
 		{"enable", "--now", "lima-guestagent.service"},
+		{"try-restart", "lima-guestagent.service"},
 	}
 	for _, args := range args {
 		cmd := exec.Command("systemctl", append([]string{"--system"}, args...)...)
