@@ -15,7 +15,7 @@ import (
 	"github.com/spf13/cobra"
 )
 
-var copyHelp = `Copy files between host and guest
+const copyHelp = `Copy files between host and guest
 
 Prefix guest filenames with the instance name and a colon.
 
@@ -23,7 +23,7 @@ Example: limactl copy default:/etc/os-release .
 `
 
 func newCopyCommand() *cobra.Command {
-	var copyCommand = &cobra.Command{
+	copyCommand := &cobra.Command{
 		Use:     "copy SOURCE ... TARGET",
 		Aliases: []string{"cp"},
 		Short:   "Copy files between host and guest",
