@@ -109,7 +109,8 @@ if [[ -n ${CHECKS["disk"]} ]]; then
 fi
 
 set -x
-"${LIMACTL_CREATE[@]}" "$FILE"
+# shellcheck disable=SC2086
+"${LIMACTL_CREATE[@]}" ${LIMACTL_CREATE_ARGS} "$FILE"
 set +x
 
 INFO "Starting \"$NAME\""
@@ -223,7 +224,7 @@ if [[ -n ${CHECKS["port-forwards"]} ]]; then
 	if [ "${NAME}" = "debian" ]; then
 		limactl shell "$NAME" sudo apt-get install -y netcat-openbsd
 	fi
-	if [ "${NAME}" = "fedora" ]; then
+	if [ "${NAME}" == "fedora" ]; then
 		limactl shell "$NAME" sudo dnf install -y nc
 	fi
 	if [ "${NAME}" = "opensuse" ]; then
@@ -300,6 +301,11 @@ if [[ -n ${CHECKS["restart"]} ]]; then
 	limactl stop "$NAME"
 	sleep 3
 
+	if [[ -n ${CHECKS["disk"]} ]]; then
+		INFO "Resize disk and verify that partition and fs size are increased"
+		limactl disk resize data --size 11G
+	fi
+
 	export ftp_proxy=my.proxy:8021
 	INFO "Restarting \"$NAME\""
 	limactl start "$NAME"
@@ -324,6 +330,10 @@ if [[ -n ${CHECKS["restart"]} ]]; then
 			ERROR "Disk does not persist across restarts"
 			exit 1
 		fi
+		if ! limactl shell "$NAME" sh -c 'df -h /mnt/lima-data/ --output=size | grep -q 11G'; then
+			ERROR "Disk FS does not resized after restart"
+			exit 1
+		fi
 	fi
 fi
 
@@ -389,6 +399,10 @@ if [[ -n ${CHECKS["snapshot-offline"]} ]]; then
 	limactl start "$NAME"
 fi
 
+if [[ $NAME == "fedora" && "$(limactl ls --json "$NAME" | jq -r .vmType)" == "vz" ]]; then
+	"${scriptdir}"/test-selinux.sh "$NAME"
+fi
+
 INFO "Stopping \"$NAME\""
 limactl stop "$NAME"
 sleep 3
