@@ -34,13 +34,17 @@ CODE=0
 # has run because it might move the directories to /mnt/data on first boot. In that
 # case changes made on restart would be lost.
 
-for f in "${LIMA_CIDATA_MNT}"/boot/*; do
-	INFO "Executing $f"
-	if ! "$f"; then
-		WARNING "Failed to execute $f"
-		CODE=1
-	fi
-done
+if [ "$LIMA_CIDATA_PLAIN" = "1" ]; then
+	INFO "Plain mode. Skipping to run boot scripts. Provisioning scripts will be still executed. Guest agent will not be running."
+else
+	for f in "${LIMA_CIDATA_MNT}"/boot/*; do
+		INFO "Executing $f"
+		if ! "$f"; then
+			WARNING "Failed to execute $f"
+			CODE=1
+		fi
+	done
+fi
 
 if [ -d "${LIMA_CIDATA_MNT}"/provision.system ]; then
 	for f in "${LIMA_CIDATA_MNT}"/provision.system/*; do
@@ -52,7 +56,7 @@ if [ -d "${LIMA_CIDATA_MNT}"/provision.system ]; then
 	done
 fi
 
-USER_SCRIPT="/home/${LIMA_CIDATA_USER}.linux/.lima-user-script"
+USER_SCRIPT="${LIMA_CIDATA_HOME}/.lima-user-script"
 if [ -d "${LIMA_CIDATA_MNT}"/provision.user ]; then
 	if [ ! -f /sbin/openrc-run ]; then
 		until [ -e "/run/user/${LIMA_CIDATA_UID}/systemd/private" ]; do sleep 3; done
