@@ -265,16 +265,17 @@ func GenerateISO9660(instDir, name string, y *limayaml.LimaYAML, udpDNSLocalPort
 	if err != nil {
 		return err
 	}
-	if firstUsernetIndex != -1 || *y.VMType == limayaml.VZ {
+
+	if len(y.DNS) > 0 {
+		for _, addr := range y.DNS {
+			args.DNSAddresses = append(args.DNSAddresses, addr.String())
+		}
+	} else if firstUsernetIndex != -1 || *y.VMType == limayaml.VZ {
 		args.DNSAddresses = append(args.DNSAddresses, args.SlirpDNS)
 	} else if *y.HostResolver.Enabled {
 		args.UDPDNSLocalPort = udpDNSLocalPort
 		args.TCPDNSLocalPort = tcpDNSLocalPort
 		args.DNSAddresses = append(args.DNSAddresses, args.SlirpDNS)
-	} else if len(y.DNS) > 0 {
-		for _, addr := range y.DNS {
-			args.DNSAddresses = append(args.DNSAddresses, addr.String())
-		}
 	} else {
 		args.DNSAddresses, err = osutil.DNSAddresses()
 		if err != nil {
@@ -428,11 +429,11 @@ func writeCIDataDir(rootPath string, layout []iso9660util.Entry) error {
 
 	for _, e := range layout {
 		if dir := path.Dir(e.Path); dir != "" && dir != "/" {
-			if err := os.MkdirAll(filepath.Join(rootPath, dir), 0700); err != nil {
+			if err := os.MkdirAll(filepath.Join(rootPath, dir), 0o700); err != nil {
 				return err
 			}
 		}
-		f, err := os.OpenFile(filepath.Join(rootPath, e.Path), os.O_CREATE|os.O_RDWR, 0700)
+		f, err := os.OpenFile(filepath.Join(rootPath, e.Path), os.O_CREATE|os.O_RDWR, 0o700)
 		if err != nil {
 			return err
 		}
