@@ -46,7 +46,6 @@ type HostAgent struct {
 	sshConfig       *ssh.SSHConfig
 	portForwarder   *portForwarder
 	onClose         []func() error // LIFO
-	guestAgentProto guestagentclient.Proto
 
 	driver   driver.Driver
 	sigintCh chan os.Signal
@@ -55,6 +54,12 @@ type HostAgent struct {
 	eventEncMu sync.Mutex
 
 	vSockPort int
+
+	clientMu sync.RWMutex
+	client   guestagentclient.GuestAgentClient
+
+	guestAgentAliveCh     chan struct{} // closed on establishing the connection
+	guestAgentAliveChOnce sync.Once
 }
 
 type options struct {
@@ -111,13 +116,10 @@ func New(instName string, stdout io.Writer, sigintCh chan os.Signal, opts ...Opt
 		}
 	}
 
-	guestAgentProto := guestagentclient.UNIX
-	if *y.VMType == limayaml.WSL2 {
-		guestAgentProto = guestagentclient.VSOCK
-	}
-
 	vSockPort := 0
-	if guestAgentProto == guestagentclient.VSOCK {
+	if *y.VMType == limayaml.VZ {
+		vSockPort = 2222
+	} else if *y.VMType == limayaml.WSL2 {
 		port, err := getFreeVSockPort()
 		if err != nil {
 			logrus.WithError(err).Error("failed to get free VSock port")
@@ -157,23 +159,24 @@ func New(instName string, stdout io.Writer, sigintCh chan os.Signal, opts ...Opt
 		Instance:     inst,
 		Yaml:         y,
 		SSHLocalPort: sshLocalPort,
+		VSockPort:    vSockPort,
 	})
 
 	a := &HostAgent{
-		y:               y,
-		sshLocalPort:    sshLocalPort,
-		udpDNSLocalPort: udpDNSLocalPort,
-		tcpDNSLocalPort: tcpDNSLocalPort,
-		instDir:         inst.Dir,
-		instName:        instName,
-		instSSHAddress:  inst.SSHAddress,
-		sshConfig:       sshConfig,
-		portForwarder:   newPortForwarder(sshConfig, sshLocalPort, rules, inst.VMType),
-		driver:          limaDriver,
-		sigintCh:        sigintCh,
-		eventEnc:        json.NewEncoder(stdout),
-		vSockPort:       vSockPort,
-		guestAgentProto: guestAgentProto,
+		y:                 y,
+		sshLocalPort:      sshLocalPort,
+		udpDNSLocalPort:   udpDNSLocalPort,
+		tcpDNSLocalPort:   tcpDNSLocalPort,
+		instDir:           inst.Dir,
+		instName:          instName,
+		instSSHAddress:    inst.SSHAddress,
+		sshConfig:         sshConfig,
+		portForwarder:     newPortForwarder(sshConfig, sshLocalPort, rules, inst.VMType),
+		driver:            limaDriver,
+		sigintCh:          sigintCh,
+		eventEnc:          json.NewEncoder(stdout),
+		vSockPort:         vSockPort,
+		guestAgentAliveCh: make(chan struct{}),
 	}
 	return a, nil
 }
@@ -197,7 +200,7 @@ func writeSSHConfigFile(inst *store.Instance, instSSHAddress string, sshLocalPor
 		return err
 	}
 	fileName := filepath.Join(inst.Dir, filenames.SSHConfig)
-	return os.WriteFile(fileName, b.Bytes(), 0600)
+	return os.WriteFile(fileName, b.Bytes(), 0o600)
 }
 
 func determineSSHLocalPort(y *limayaml.LimaYAML, instName string) (int, error) {
@@ -289,6 +292,7 @@ func (a *HostAgent) Run(ctx context.Context) error {
 		}
 		a.emitEvent(ctx, exitingEv)
 	}()
+	adjustNofileRlimit()
 
 	firstUsernetIndex := limayaml.FirstUsernetIndex(a.y)
 	if firstUsernetIndex == -1 && *a.y.HostResolver.Enabled {
@@ -344,7 +348,7 @@ func (a *HostAgent) Run(ctx context.Context) error {
 		if err := a.driver.ChangeDisplayPassword(ctx, vncpasswd); err != nil {
 			return err
 		}
-		if err := os.WriteFile(vncpwdfile, []byte(vncpasswd), 0600); err != nil {
+		if err := os.WriteFile(vncpwdfile, []byte(vncpasswd), 0o600); err != nil {
 			return err
 		}
 		if strings.Contains(vncoptions, "to=") {
@@ -360,7 +364,7 @@ func (a *HostAgent) Run(ctx context.Context) error {
 			vncdisplay = net.JoinHostPort(vnchost, vncnum)
 		}
 		vncfile := filepath.Join(a.instDir, filenames.VNCDisplayFile)
-		if err := os.WriteFile(vncfile, []byte(vncdisplay), 0600); err != nil {
+		if err := os.WriteFile(vncfile, []byte(vncdisplay), 0o600); err != nil {
 			return err
 		}
 		vncurl := "vnc://" + net.JoinHostPort(vnchost, vncport)
@@ -492,6 +496,21 @@ sudo chown -R "${USER}" /run/host-services`
 	if err := a.waitForRequirements("optional", a.optionalRequirements()); err != nil {
 		errs = append(errs, err)
 	}
+	if !*a.y.Plain {
+		logrus.Info("Waiting for the guest agent to be running")
+		select {
+		case <-a.guestAgentAliveCh:
+			// NOP
+		case <-time.After(time.Minute):
+			err := errors.New("guest agent does not seem to be running; port forwards will not work")
+			if *a.y.VMType == limayaml.WSL2 {
+				// geustagent is currently not available for WSL2: https://github.com/lima-vm/lima/issues/2025
+				logrus.Warn(err)
+			} else {
+				errs = append(errs, err)
+			}
+		}
+	}
 	if err := a.waitForRequirements("final", a.finalRequirements()); err != nil {
 		errs = append(errs, err)
 	}
@@ -542,9 +561,6 @@ func (a *HostAgent) watchGuestAgentEvents(ctx context.Context) {
 		}
 	}
 
-	localUnix := filepath.Join(a.instDir, filenames.GuestAgentSock)
-	remoteUnix := "/run/lima-guestagent.sock"
-
 	a.onClose = append(a.onClose, func() error {
 		logrus.Debugf("Stop forwarding unix sockets")
 		var errs []error
@@ -557,27 +573,18 @@ func (a *HostAgent) watchGuestAgentEvents(ctx context.Context) {
 				}
 			}
 		}
-		if err := forwardSSH(context.Background(), a.sshConfig, a.sshLocalPort, localUnix, remoteUnix, verbCancel, false); err != nil {
-			errs = append(errs, err)
-		}
 		return errors.Join(errs...)
 	})
-
-	guestSocketAddr := localUnix
-	if a.guestAgentProto == guestagentclient.VSOCK {
-		guestSocketAddr = fmt.Sprintf("0.0.0.0:%d", a.vSockPort)
-	}
-
 	for {
-		if !isGuestAgentSocketAccessible(ctx, guestSocketAddr, a.guestAgentProto, a.instName) {
-			if a.guestAgentProto != guestagentclient.VSOCK {
-				_ = forwardSSH(ctx, a.sshConfig, a.sshLocalPort, localUnix, remoteUnix, verbForward, false)
-			}
-		}
-		if err := a.processGuestAgentEvents(ctx, guestSocketAddr, a.guestAgentProto, a.instName); err != nil {
-			if !errors.Is(err, context.Canceled) {
-				logrus.WithError(err).Warn("connection to the guest agent was closed unexpectedly")
+		client, err := a.getOrCreateClient(ctx)
+		if err == nil {
+			if err := a.processGuestAgentEvents(ctx, client); err != nil {
+				if !errors.Is(err, context.Canceled) {
+					logrus.WithError(err).Warn("connection to the guest agent was closed unexpectedly", err)
+				}
 			}
+		} else {
+			logrus.WithError(err).Warn("connection to the guest agent was closed unexpectedly", err)
 		}
 		select {
 		case <-ctx.Done():
@@ -587,25 +594,40 @@ func (a *HostAgent) watchGuestAgentEvents(ctx context.Context) {
 	}
 }
 
-func isGuestAgentSocketAccessible(ctx context.Context, localUnix string, proto guestagentclient.Proto, instanceName string) bool {
-	client, err := guestagentclient.NewGuestAgentClient(localUnix, proto, instanceName)
-	if err != nil {
-		return false
-	}
-	_, err = client.Info(ctx)
+func isGuestAgentSocketAccessible(ctx context.Context, client guestagentclient.GuestAgentClient) bool {
+	_, err := client.Info(ctx)
 	return err == nil
 }
 
-func (a *HostAgent) processGuestAgentEvents(ctx context.Context, localUnix string, proto guestagentclient.Proto, instanceName string) error {
-	client, err := guestagentclient.NewGuestAgentClient(localUnix, proto, instanceName)
+func (a *HostAgent) getOrCreateClient(ctx context.Context) (guestagentclient.GuestAgentClient, error) {
+	a.clientMu.Lock()
+	defer a.clientMu.Unlock()
+	if a.client != nil && isGuestAgentSocketAccessible(ctx, a.client) {
+		return a.client, nil
+	}
+	var err error
+	a.client, err = a.createClient(ctx)
+	return a.client, err
+}
+
+func (a *HostAgent) createClient(ctx context.Context) (guestagentclient.GuestAgentClient, error) {
+	conn, err := a.driver.GuestAgentConn(ctx)
 	if err != nil {
-		return err
+		return nil, err
 	}
 
+	return guestagentclient.NewGuestAgentClient(conn)
+}
+
+func (a *HostAgent) processGuestAgentEvents(ctx context.Context, client guestagentclient.GuestAgentClient) error {
 	info, err := client.Info(ctx)
 	if err != nil {
 		return err
 	}
+	logrus.Info("Guest agent is running")
+	a.guestAgentAliveChOnce.Do(func() {
+		close(a.guestAgentAliveCh)
+	})
 
 	logrus.Debugf("guest agent info: %+v", info)
 
@@ -679,7 +701,7 @@ func forwardSSH(ctx context.Context, sshConfig *ssh.SSHConfig, port int, local,
 					logrus.WithError(err).Warnf("Failed to clean up %q (host) before setting up forwarding", local)
 				}
 			}
-			if err := os.MkdirAll(filepath.Dir(local), 0750); err != nil {
+			if err := os.MkdirAll(filepath.Dir(local), 0o750); err != nil {
 				return fmt.Errorf("can't create directory for local socket %q: %w", local, err)
 			}
 		case verbCancel:
@@ -733,7 +755,7 @@ func copyToHost(ctx context.Context, sshConfig *ssh.SSHConfig, port int, local,
 		remote,
 	)
 	logrus.Infof("Copying config from %s to %s", remote, local)
-	if err := os.MkdirAll(filepath.Dir(local), 0700); err != nil {
+	if err := os.MkdirAll(filepath.Dir(local), 0o700); err != nil {
 		return fmt.Errorf("can't create directory for local file %q: %w", local, err)
 	}
 	cmd := exec.CommandContext(ctx, sshConfig.Binary(), args...)
@@ -741,7 +763,7 @@ func copyToHost(ctx context.Context, sshConfig *ssh.SSHConfig, port int, local,
 	if err != nil {
 		return fmt.Errorf("failed to run %v: %q: %w", cmd.Args, string(out), err)
 	}
-	if err := os.WriteFile(local, out, 0600); err != nil {
+	if err := os.WriteFile(local, out, 0o600); err != nil {
 		return fmt.Errorf("can't write to local file %q: %w", local, err)
 	}
 	return nil
