@@ -156,3 +156,7 @@ func (plf *pseudoLoopbackForwarder) Close() error {
 	_ = plf.ln.Close()
 	return plf.onClose()
 }
+
+func getFreeVSockPort() (int, error) {
+	return 0, nil
+}
