@@ -17,6 +17,7 @@ import (
 	"time"
 
 	"github.com/lima-vm/lima/pkg/networks/usernet"
+	"github.com/lima-vm/lima/pkg/osutil"
 
 	"github.com/coreos/go-semver/semver"
 	"github.com/digitalocean/go-qemu/qmp"
@@ -42,7 +43,9 @@ type Config struct {
 }
 
 // MinimumQemuVersion is the minimum supported QEMU version
-const MinimumQemuVersion = "4.0.0"
+const (
+	MinimumQemuVersion = "4.0.0"
+)
 
 // EnsureDisk also ensures the kernel and the initrd
 func EnsureDisk(cfg Config) error {
@@ -70,7 +73,7 @@ func EnsureDisk(cfg Config) error {
 					continue
 				}
 				if f.Kernel.Cmdline != "" {
-					if err := os.WriteFile(kernelCmdline, []byte(f.Kernel.Cmdline), 0644); err != nil {
+					if err := os.WriteFile(kernelCmdline, []byte(f.Kernel.Cmdline), 0o644); err != nil {
 						errs[i] = err
 						continue
 					}
@@ -134,6 +137,17 @@ func CreateDataDisk(dir, format string, size int) error {
 	return nil
 }
 
+func ResizeDataDisk(dir, format string, size int) error {
+	dataDisk := filepath.Join(dir, filenames.DataDisk)
+
+	args := []string{"resize", "-f", format, dataDisk, strconv.Itoa(size)}
+	cmd := exec.Command("qemu-img", args...)
+	if out, err := cmd.CombinedOutput(); err != nil {
+		return fmt.Errorf("failed to run %v: %q: %w", cmd.Args, string(out), err)
+	}
+	return nil
+}
+
 func newQmpClient(cfg Config) (*qmp.SocketMonitor, error) {
 	qmpSock := filepath.Join(cfg.InstanceDir, filenames.QMPSock)
 	qmpClient, err := qmp.NewSocketMonitor("unix", qmpSock, 5*time.Second)
@@ -398,25 +412,6 @@ func showDarwinARM64HVFQEMU620Warning(exe, accel string, features *features) {
 	logrus.Warn(w)
 }
 
-func getMacOSProductVersion() (*semver.Version, error) {
-	cmd := exec.Command("sw_vers", "-productVersion")
-	// output is like "12.3.1\n"
-	b, err := cmd.Output()
-	if err != nil {
-		return nil, fmt.Errorf("failed to execute %v: %w", cmd.Args, err)
-	}
-	verTrimmed := strings.TrimSpace(string(b))
-	// macOS 12.4 returns just "12.4\n"
-	for strings.Count(verTrimmed, ".") < 2 {
-		verTrimmed += ".0"
-	}
-	verSem, err := semver.NewVersion(verTrimmed)
-	if err != nil {
-		return nil, fmt.Errorf("failed to parse macOS version %q: %w", verTrimmed, err)
-	}
-	return verSem, nil
-}
-
 // adjustMemBytesDarwinARM64HVF adjusts the memory to be <= 3 GiB, only when the following conditions are met:
 //
 // - Host OS   <  macOS 12.4
@@ -443,7 +438,7 @@ func adjustMemBytesDarwinARM64HVF(memBytes int64, accel string, features *featur
 	if !features.VersionGEQ7 {
 		return memBytes
 	}
-	macOSProductVersion, err := getMacOSProductVersion()
+	macOSProductVersion, err := osutil.ProductVersion()
 	if err != nil {
 		logrus.Warn(err)
 		return memBytes
@@ -660,7 +655,7 @@ func Cmdline(cfg Config) (string, []string, error) {
 	}
 
 	// Network
-	//Configure default usernetwork with limayaml.MACAddress(driver.Instance.Dir) for eth0 interface
+	// Configure default usernetwork with limayaml.MACAddress(driver.Instance.Dir) for eth0 interface
 	firstUsernetIndex := limayaml.FirstUsernetIndex(y)
 	if firstUsernetIndex == -1 {
 		args = append(args, "-netdev", fmt.Sprintf("user,id=net0,net=%s,dhcpstart=%s,hostfwd=tcp:127.0.0.1:%d-:22",
@@ -682,7 +677,7 @@ func Cmdline(cfg Config) (string, []string, error) {
 				return "", nil, err
 			}
 
-			//Handle usernet connections
+			// Handle usernet connections
 			isUsernet, err := nwCfg.Usernet(nw.Lima)
 			if err != nil {
 				return "", nil, err
@@ -802,8 +797,8 @@ func Cmdline(cfg Config) (string, []string, error) {
 			args = append(args, "-device", "virtio-"+input+"-pci")
 		} else { // kernel panic with virtio and old versions of QEMU
 			args = append(args, "-vga", "none", "-device", "ramfb")
-			args = append(args, "-device", "usb-kbd,bus=usb-bus.0")
-			args = append(args, "-device", "usb-"+input+",bus=usb-bus.0")
+			args = append(args, "-device", "usb-kbd,bus=usb-bus")
+			args = append(args, "-device", "usb-"+input+",bus=usb-bus")
 		}
 		args = append(args, "-device", "qemu-xhci,id=usb-bus")
 	}
@@ -867,7 +862,7 @@ func Cmdline(cfg Config) (string, []string, error) {
 			if err != nil {
 				return "", nil, err
 			}
-			if err := os.MkdirAll(location, 0755); err != nil {
+			if err := os.MkdirAll(location, 0o755); err != nil {
 				return "", nil, err
 			}
 
@@ -906,6 +901,12 @@ func Cmdline(cfg Config) (string, []string, error) {
 	args = append(args, "-chardev", fmt.Sprintf("socket,id=%s,path=%s,server=on,wait=off", qmpChardev, qmpSock))
 	args = append(args, "-qmp", "chardev:"+qmpChardev)
 
+	// Guest agent via serialport
+	guestSock := filepath.Join(cfg.InstanceDir, filenames.GuestAgentSock)
+	args = append(args, "-chardev", fmt.Sprintf("socket,path=%s,server=on,wait=off,id=qga0", guestSock))
+	args = append(args, "-device", "virtio-serial")
+	args = append(args, "-device", "virtserialport,chardev=qga0,name="+filenames.VirtioPort)
+
 	// QEMU process
 	args = append(args, "-name", "lima-"+cfg.Name)
 	args = append(args, "-pidfile", filepath.Join(cfg.InstanceDir, filenames.PIDFile(*y.VMType)))
