@@ -13,8 +13,10 @@ import (
 	"text/template"
 	"time"
 
+	"github.com/coreos/go-semver/semver"
 	"github.com/lima-vm/lima/pkg/driver"
 	"github.com/lima-vm/lima/pkg/driverutil"
+	"github.com/lima-vm/lima/pkg/osutil"
 	"github.com/lima-vm/lima/pkg/qemu"
 	"github.com/lima-vm/lima/pkg/qemu/entitlementutil"
 
@@ -72,7 +74,7 @@ type Prepared struct {
 }
 
 // Prepare ensures the disk, the nerdctl archive, etc.
-func Prepare(_ context.Context, inst *store.Instance) (*Prepared, error) {
+func Prepare(ctx context.Context, inst *store.Instance) (*Prepared, error) {
 	y, err := inst.LoadYAML()
 	if err != nil {
 		return nil, err
@@ -87,6 +89,10 @@ func Prepare(_ context.Context, inst *store.Instance) (*Prepared, error) {
 		return nil, err
 	}
 
+	if err := limaDriver.Initialize(ctx); err != nil {
+		return nil, err
+	}
+
 	// Check if the instance has been created (the base disk already exists)
 	created := false
 	baseDisk := filepath.Join(inst.Dir, filenames.BaseDisk)
@@ -114,18 +120,26 @@ func Start(ctx context.Context, inst *store.Instance) error {
 	if _, err := os.Stat(haPIDPath); !errors.Is(err, os.ErrNotExist) {
 		return fmt.Errorf("instance %q seems running (hint: remove %q if the instance is not actually running)", inst.Name, haPIDPath)
 	}
+	logrus.Infof("Starting the instance %q with VM driver %q", inst.Name, inst.VMType)
 
 	haSockPath := filepath.Join(inst.Dir, filenames.HostAgentSock)
 
 	// Ask the user to sign the qemu binary with the "com.apple.security.hypervisor" if needed.
 	// Workaround for https://github.com/lima-vm/lima/issues/1742
 	if runtime.GOOS == "darwin" && inst.VMType == limayaml.QEMU {
-		qExe, _, err := qemu.Exe(inst.Arch)
+		macOSProductVersion, err := osutil.ProductVersion()
 		if err != nil {
-			return fmt.Errorf("failed to find the QEMU binary for the architecture %q: %w", inst.Arch, err)
+			return err
 		}
-		if accel := qemu.Accel(inst.Arch); accel == "hvf" {
-			entitlementutil.AskToSignIfNotSignedProperly(qExe)
+		// The codesign --xml option is only available on macOS Monterey and later
+		if !macOSProductVersion.LessThan(*semver.New("12.0.0")) {
+			qExe, _, err := qemu.Exe(inst.Arch)
+			if err != nil {
+				return fmt.Errorf("failed to find the QEMU binary for the architecture %q: %w", inst.Arch, err)
+			}
+			if accel := qemu.Accel(inst.Arch); accel == "hvf" {
+				entitlementutil.AskToSignIfNotSignedProperly(qExe)
+			}
 		}
 	}
 
@@ -258,7 +272,7 @@ func watchHostAgentEvents(ctx context.Context, inst *store.Instance, haStdoutPat
 			} else {
 				logrus.Infof("READY. Run `%s` to open the shell.", LimactlShellCmd(inst.Name))
 			}
-			ShowMessage(inst)
+			_ = ShowMessage(inst)
 			err = nil
 			return true
 		}
