@@ -1,5 +1,4 @@
 //go:build darwin && !no_vz
-// +build darwin,!no_vz
 
 package vz
 
@@ -31,6 +30,13 @@ import (
 	"github.com/sirupsen/logrus"
 )
 
+// diskImageCachingMode is set to DiskImageCachingModeCached so as to avoid disk corruption on ARM:
+// - https://github.com/utmapp/UTM/issues/4840#issuecomment-1824340975
+// - https://github.com/utmapp/UTM/issues/4840#issuecomment-1824542732
+//
+// Eventually we may bring this back to DiskImageCachingModeAutomatic when the corruption issue is properly fixed.
+const diskImageCachingMode = vz.DiskImageCachingModeCached
+
 type virtualMachineWrapper struct {
 	*vz.VirtualMachine
 	mu      sync.Mutex
@@ -67,7 +73,7 @@ func startVM(ctx context.Context, driver *driver.BaseDriver) (*virtualMachineWra
 		}
 	}()
 	go func() {
-		//Handle errors via errCh and handle stop vm during context close
+		// Handle errors via errCh and handle stop vm during context close
 		defer func() {
 			for i := range vmNetworkFiles {
 				vmNetworkFiles[i].Close()
@@ -89,7 +95,7 @@ func startVM(ctx context.Context, driver *driver.BaseDriver) (*virtualMachineWra
 						logrus.Errorf("pidfile %q already exists", pidFile)
 						errCh <- err
 					}
-					if err := os.WriteFile(pidFile, []byte(strconv.Itoa(os.Getpid())+"\n"), 0644); err != nil {
+					if err := os.WriteFile(pidFile, []byte(strconv.Itoa(os.Getpid())+"\n"), 0o644); err != nil {
 						logrus.Errorf("error writing to pid fil %q", pidFile)
 						errCh <- err
 					}
@@ -105,7 +111,7 @@ func startVM(ctx context.Context, driver *driver.BaseDriver) (*virtualMachineWra
 					wrapper.mu.Lock()
 					wrapper.stopped = true
 					wrapper.mu.Unlock()
-					usernetClient.UnExposeSSH(driver.SSHLocalPort)
+					_ = usernetClient.UnExposeSSH(driver.SSHLocalPort)
 					errCh <- errors.New("vz driver state stopped")
 				default:
 					logrus.Debugf("[VZ] - vm state change: %q", newState)
@@ -120,7 +126,7 @@ func startVM(ctx context.Context, driver *driver.BaseDriver) (*virtualMachineWra
 func startUsernet(ctx context.Context, driver *driver.BaseDriver) (*usernet.Client, error) {
 	firstUsernetIndex := limayaml.FirstUsernetIndex(driver.Yaml)
 	if firstUsernetIndex == -1 {
-		//Start a in-process gvisor-tap-vsock
+		// Start a in-process gvisor-tap-vsock
 		endpointSock, err := usernet.SockWithDirectory(driver.Instance.Dir, "", usernet.EndpointSock)
 		if err != nil {
 			return nil, err
@@ -279,10 +285,10 @@ func newVirtioNetworkDeviceConfiguration(attachment vz.NetworkDeviceAttachment,
 func attachNetwork(driver *driver.BaseDriver, vmConfig *vz.VirtualMachineConfiguration) error {
 	var configurations []*vz.VirtioNetworkDeviceConfiguration
 
-	//Configure default usernetwork with limayaml.MACAddress(driver.Instance.Dir) for eth0 interface
+	// Configure default usernetwork with limayaml.MACAddress(driver.Instance.Dir) for eth0 interface
 	firstUsernetIndex := limayaml.FirstUsernetIndex(driver.Yaml)
 	if firstUsernetIndex == -1 {
-		//slirp network using gvisor netstack
+		// slirp network using gvisor netstack
 		vzSock, err := usernet.SockWithDirectory(driver.Instance.Dir, "", usernet.FDSock)
 		if err != nil {
 			return err
@@ -435,7 +441,7 @@ func attachDisks(driver *driver.BaseDriver, vmConfig *vz.VirtualMachineConfigura
 	if err = validateDiskFormat(diffDiskPath); err != nil {
 		return err
 	}
-	diffDiskAttachment, err := vz.NewDiskImageStorageDeviceAttachmentWithCacheAndSync(diffDiskPath, false, vz.DiskImageCachingModeAutomatic, vz.DiskImageSynchronizationModeFsync)
+	diffDiskAttachment, err := vz.NewDiskImageStorageDeviceAttachmentWithCacheAndSync(diffDiskPath, false, diskImageCachingMode, vz.DiskImageSynchronizationModeFsync)
 	if err != nil {
 		return err
 	}
@@ -466,7 +472,7 @@ func attachDisks(driver *driver.BaseDriver, vmConfig *vz.VirtualMachineConfigura
 		if err = nativeimgutil.ConvertToRaw(extraDiskPath, extraDiskPath, nil, true); err != nil {
 			return fmt.Errorf("failed to convert extra disk %q to a raw disk: %w", extraDiskPath, err)
 		}
-		extraDiskPathAttachment, err := vz.NewDiskImageStorageDeviceAttachmentWithCacheAndSync(extraDiskPath, false, vz.DiskImageCachingModeAutomatic, vz.DiskImageSynchronizationModeFsync)
+		extraDiskPathAttachment, err := vz.NewDiskImageStorageDeviceAttachmentWithCacheAndSync(extraDiskPath, false, diskImageCachingMode, vz.DiskImageSynchronizationModeFsync)
 		if err != nil {
 			return fmt.Errorf("failed to create disk attachment for extra disk %q: %w", extraDiskPath, err)
 		}
@@ -527,7 +533,7 @@ func attachFolderMounts(driver *driver.BaseDriver, vmConfig *vz.VirtualMachineCo
 				return err
 			}
 			if _, err := os.Stat(expandedPath); errors.Is(err, os.ErrNotExist) {
-				err := os.MkdirAll(expandedPath, 0750)
+				err := os.MkdirAll(expandedPath, 0o750)
 				if err != nil {
 					return err
 				}
@@ -667,7 +673,7 @@ func getMachineIdentifier(driver *driver.BaseDriver) (*vz.GenericMachineIdentifi
 		if err != nil {
 			return nil, err
 		}
-		err = os.WriteFile(identifier, machineIdentifier.DataRepresentation(), 0666)
+		err = os.WriteFile(identifier, machineIdentifier.DataRepresentation(), 0o666)
 		if err != nil {
 			return nil, err
 		}
