@@ -1,5 +1,4 @@
 //go:build darwin && !no_vz
-// +build darwin,!no_vz
 
 package vz
 
@@ -7,19 +6,52 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"net"
 	"path/filepath"
 	"time"
 
-	"github.com/lima-vm/lima/pkg/reflectutil"
-
 	"github.com/Code-Hex/vz/v3"
 
 	"github.com/sirupsen/logrus"
 
 	"github.com/lima-vm/lima/pkg/driver"
 	"github.com/lima-vm/lima/pkg/limayaml"
+	"github.com/lima-vm/lima/pkg/reflectutil"
 )
 
+var knownYamlProperties = []string{
+	"AdditionalDisks",
+	"Arch",
+	"Audio",
+	"CACertificates",
+	"Containerd",
+	"CopyToHost",
+	"CPUs",
+	"CPUType",
+	"Disk",
+	"DNS",
+	"Env",
+	"Firmware",
+	"GuestInstallPrefix",
+	"HostResolver",
+	"Images",
+	"Memory",
+	"Message",
+	"Mounts",
+	"MountType",
+	"Networks",
+	"OS",
+	"Plain",
+	"PortForwards",
+	"Probes",
+	"PropagateProxyEnv",
+	"Provision",
+	"Rosetta",
+	"SSH",
+	"Video",
+	"VMType",
+}
+
 const Enabled = true
 
 type LimaVzDriver struct {
@@ -35,7 +67,7 @@ func New(driver *driver.BaseDriver) *LimaVzDriver {
 }
 
 func (l *LimaVzDriver) Validate() error {
-	//Calling NewEFIBootLoader to do required version check for latest APIs
+	// Calling NewEFIBootLoader to do required version check for latest APIs
 	_, err := vz.NewEFIBootLoader()
 	if errors.Is(err, vz.ErrUnsupportedOSVersion) {
 		return fmt.Errorf("VZ driver requires macOS 13 or higher to run")
@@ -46,36 +78,7 @@ func (l *LimaVzDriver) Validate() error {
 	if *l.Yaml.Firmware.LegacyBIOS {
 		return fmt.Errorf("`firmware.legacyBIOS` configuration is not supported for VZ driver")
 	}
-	if unknown := reflectutil.UnknownNonEmptyFields(l.Yaml, "VMType",
-		"Arch",
-		"Images",
-		"CPUs",
-		"CPUType",
-		"Memory",
-		"Disk",
-		"Mounts",
-		"MountType",
-		"SSH",
-		"Firmware",
-		"Provision",
-		"Containerd",
-		"GuestInstallPrefix",
-		"Probes",
-		"PortForwards",
-		"Message",
-		"Networks",
-		"Env",
-		"DNS",
-		"HostResolver",
-		"PropagateProxyEnv",
-		"CACertificates",
-		"Rosetta",
-		"AdditionalDisks",
-		"Audio",
-		"Video",
-		"OS",
-		"Plain",
-	); len(unknown) > 0 {
+	if unknown := reflectutil.UnknownNonEmptyFields(l.Yaml, knownYamlProperties...); len(unknown) > 0 {
 		logrus.Warnf("vmType %s: ignoring %+v", *l.Yaml.VMType, unknown)
 	}
 
@@ -130,6 +133,11 @@ func (l *LimaVzDriver) Validate() error {
 	return nil
 }
 
+func (l *LimaVzDriver) Initialize(_ context.Context) error {
+	_, err := getMachineIdentifier(l.BaseDriver)
+	return err
+}
+
 func (l *LimaVzDriver) CreateDisk() error {
 	return EnsureDisk(l.BaseDriver)
 }
@@ -193,3 +201,13 @@ func (l *LimaVzDriver) Stop(_ context.Context) error {
 
 	return errors.New("vz: CanRequestStop is not supported")
 }
+
+func (l *LimaVzDriver) GuestAgentConn(_ context.Context) (net.Conn, error) {
+	for _, socket := range l.machine.SocketDevices() {
+		connect, err := socket.Connect(uint32(l.VSockPort))
+		if err == nil && connect.SourcePort() != 0 {
+			return connect, nil
+		}
+	}
+	return nil, fmt.Errorf("unable to connect to guest agent via vsock port 2222")
+}
